==> tutti-ui-swing-1.0.2-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIHandler.java <==

package fr.ifremer.tutti.ui.swing.content.operation.catches.species;

/*
 * #%L
 * Tutti :: UI
 * $Id: SelectSpeciesUIHandler.java 512 2013-03-01 20:37:07Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class SelectSpeciesUIHandler extends AbstractTuttiUIHandler<SelectSpeciesUIModel, SelectSpeciesUI> {

    private static final Log log = LogFactory.getLog(SelectSpeciesUIHandler.class);

    public SelectSpeciesUIHandler(TuttiUI parentUI, SelectSpeciesUI ui) {
        super(parentUI.getHandler().getContext(), ui);
    }

    @Override
    public void beforeInitUI() {
        SelectSpeciesUIModel model = new SelectSpeciesUIModel();
        ui.setContextValue(model);
    }

    @Override
    public void afterInitUI() {
        initUI(ui);

        initBeanComboBox(ui.getSpeciesCombo(),
                         Lists.<Species>newArrayList(),
                         null);

        getModel().addPropertyChangeListener(SelectSpeciesUIModel.PROPERTY_SPECIES,
                                             new PropertyChangeListener() {

                                                 public void propertyChange(PropertyChangeEvent evt) {
                                                     ui.getSpeciesCombo().getHandler().sortData();
                                                 }
                                             });
    }

    @Override
    public void onCloseUI() {
        if (log.isInfoEnabled()) {
            log.info("Closing: " + ui);
        }
    }

    @Override
    public SwingValidator<SelectSpeciesUIModel> getValidator() {
        return null;
    }

}

==> tutti-ui-swing-1.0.3-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIHandler.java <==

package fr.ifremer.tutti.ui.swing.content.operation.catches.species;

/*
 * #%L
 * Tutti :: UI
 * $Id: SelectSpeciesUIHandler.java 581 2013-03-12 09:10:25Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class SelectSpeciesUIHandler extends AbstractTuttiUIHandler<SelectSpeciesUIModel, SelectSpeciesUI> {

    private static final Log log = LogFactory.getLog(SelectSpeciesUIHandler.class);

    public SelectSpeciesUIHandler(TuttiUI parentUI, SelectSpeciesUI ui) {
        super(parentUI.getHandler().getContext(), ui);
    }

    @Override
    public void beforeInitUI() {
        SelectSpeciesUIModel model = new SelectSpeciesUIModel();
        ui.setContextValue(model);
    }

    @Override
    public void afterInitUI() {
        initUI(ui);

        initBeanFilterableComboBox(ui.getSpeciesCombo(),
                                   Lists.<Species>newArrayList(),
                                   null);

        getModel().addPropertyChangeListener(
                SelectSpeciesUIModel.PROPERTY_SPECIES,
                new PropertyChangeListener() {

                    public void propertyChange(PropertyChangeEvent evt) {
                        ui.getSpeciesCombo().getHandler().sortData();
                    }
                });
    }

    @Override
    public void onCloseUI() {
        if (log.isDebugEnabled()) {
            log.debug("closing: " + ui);
        }
    }

    @Override
    public SwingValidator<SelectSpeciesUIModel> getValidator() {
        return null;
    }

    public void validate() {
        closeDialog(ui);
    }

    public void cancel() {
        getModel().setSelectedSpecies(null);
        closeDialog(ui);
    }
}
